FactoryGirl.define do
  factory :service do
    project factory: :empty_project
  end
end
